#!/usr/bin/env python

"""parseli (save, rows o' json, and time)"""

__version__ = "0.0.44"
__author__ = [
    "Mek <michael.karpeles@gmail.com>"
]
__license__ = "public domain"
__contributors__ = "see AUTHORS"

from parseli import getli, crawli, parseli



#!/usr/bin/env python
#-*- coding: utf-8

"""
    parseli.utils
    ~~~~~~~~~~~~~
    Utilities taken from various sources, including web.py

    :copyright: (c) 2012 by Aaron Swartz <me@aaronsw.com>, Anand Chitipothu <anandology@gmail.com>
    :license: See web.py license - https://github.com/webpy/webpy/blob/master/LICENSE.txt
"""

__all__ = ["Storage"]

class Storage(dict):
    """
    A Storage object is like a dictionary except `obj.foo` can be used
    in addition to `obj['foo']`.
    
        >>> o = storage(a=1)
        >>> o.a
        1
        >>> o['a']
        1
        >>> o.a = 2
        >>> o['a']
        2
        >>> del o.a
        >>> o.a
        Traceback (most recent call last):
            ...
        AttributeError: 'a'
    
    """
    def __getattr__(self, key): 
        try:
            return self[key]
        except KeyError, k:
            raise AttributeError, k
    
    def __setattr__(self, key, value): 
        self[key] = value
    
    def __delattr__(self, key):
        try:
            del self[key]
        except KeyError, k:
            raise AttributeError, k
    
    def __repr__(self):     
        return '<Storage ' + dict.__repr__(self) + '>'




#-*- coding: utf-8 -*-

"""
    parseli
    ~~~~~~~
    Dependencies

    Setup
    `````
    $ sudo pip install -e .
    $ sudo rm -rf build
"""

from distutils.core import setup

setup(
    name='parseli',
    version='0.0.44',
    url='',
    author='mek',
    author_email='michael.karpeles@gmail.com',
    packages=[
        'parseli',
        'test'
        ],
    platforms='any',
    scripts=['scripts/parseli'],
    license='LICENSE',
    install_requires=[
        'beautifulsoup',
    ],
    description="Parseli cooks public LinkedIn profile pages into json.",
    long_description=open('README.md').read(),
)
